@@ -77,6 +77,8 @@ class InitrdFile(object):
             arch_cmd = '/usr/bin/lz4'
         elif "XZ" in rdtype:
             arch_cmd = '/usr/bin/xz'
+        elif "Zstandard" in rdtype:
+            arch_cmd = "/usr/bin/zstd"
         else:
             arch_cmd = '/bin/gzip'
         skipcpio_cmd = "/usr/lib/dracut/skipcpio"
